"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeSecurityPolicyXAdaptiveProtectionConfigXLayer7DdosDefenseConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FIELD_NUMBER: builtins.int
    RULE_VISIBILITY_FIELD_NUMBER: builtins.int
    enable: builtins.bool
    rule_visibility: builtins.str
    def __init__(
        self,
        *,
        enable: builtins.bool = ...,
        rule_visibility: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable", b"enable", "rule_visibility", b"rule_visibility"]) -> None: ...

global___ComputeSecurityPolicyXAdaptiveProtectionConfigXLayer7DdosDefenseConfig = ComputeSecurityPolicyXAdaptiveProtectionConfigXLayer7DdosDefenseConfig

@typing_extensions.final
class ComputeSecurityPolicyXAdaptiveProtectionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAYER_7_DDOS_DEFENSE_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def layer_7_ddos_defense_config(self) -> global___ComputeSecurityPolicyXAdaptiveProtectionConfigXLayer7DdosDefenseConfig: ...
    def __init__(
        self,
        *,
        layer_7_ddos_defense_config: global___ComputeSecurityPolicyXAdaptiveProtectionConfigXLayer7DdosDefenseConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["layer_7_ddos_defense_config", b"layer_7_ddos_defense_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["layer_7_ddos_defense_config", b"layer_7_ddos_defense_config"]) -> None: ...

global___ComputeSecurityPolicyXAdaptiveProtectionConfig = ComputeSecurityPolicyXAdaptiveProtectionConfig

@typing_extensions.final
class ComputeSecurityPolicyXAdvancedOptionsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JSON_PARSING_FIELD_NUMBER: builtins.int
    LOG_LEVEL_FIELD_NUMBER: builtins.int
    json_parsing: builtins.str
    log_level: builtins.str
    def __init__(
        self,
        *,
        json_parsing: builtins.str = ...,
        log_level: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["json_parsing", b"json_parsing", "log_level", b"log_level"]) -> None: ...

global___ComputeSecurityPolicyXAdvancedOptionsConfig = ComputeSecurityPolicyXAdvancedOptionsConfig

@typing_extensions.final
class ComputeSecurityPolicyXRuleXMatchXConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SRC_IP_RANGES_FIELD_NUMBER: builtins.int
    @property
    def src_ip_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        src_ip_ranges: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["src_ip_ranges", b"src_ip_ranges"]) -> None: ...

global___ComputeSecurityPolicyXRuleXMatchXConfig = ComputeSecurityPolicyXRuleXMatchXConfig

@typing_extensions.final
class ComputeSecurityPolicyXRuleXMatchXExpr(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPRESSION_FIELD_NUMBER: builtins.int
    expression: builtins.str
    def __init__(
        self,
        *,
        expression: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["expression", b"expression"]) -> None: ...

global___ComputeSecurityPolicyXRuleXMatchXExpr = ComputeSecurityPolicyXRuleXMatchXExpr

@typing_extensions.final
class ComputeSecurityPolicyXRuleXMatch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSIONED_EXPR_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    EXPR_FIELD_NUMBER: builtins.int
    versioned_expr: builtins.str
    @property
    def config(self) -> global___ComputeSecurityPolicyXRuleXMatchXConfig: ...
    @property
    def expr(self) -> global___ComputeSecurityPolicyXRuleXMatchXExpr: ...
    def __init__(
        self,
        *,
        versioned_expr: builtins.str = ...,
        config: global___ComputeSecurityPolicyXRuleXMatchXConfig | None = ...,
        expr: global___ComputeSecurityPolicyXRuleXMatchXExpr | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "expr", b"expr"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "expr", b"expr", "versioned_expr", b"versioned_expr"]) -> None: ...

global___ComputeSecurityPolicyXRuleXMatch = ComputeSecurityPolicyXRuleXMatch

@typing_extensions.final
class ComputeSecurityPolicyXRuleXRateLimitOptionsXBanThreshold(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    INTERVAL_SEC_FIELD_NUMBER: builtins.int
    count: builtins.float
    interval_sec: builtins.float
    def __init__(
        self,
        *,
        count: builtins.float = ...,
        interval_sec: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "interval_sec", b"interval_sec"]) -> None: ...

global___ComputeSecurityPolicyXRuleXRateLimitOptionsXBanThreshold = ComputeSecurityPolicyXRuleXRateLimitOptionsXBanThreshold

@typing_extensions.final
class ComputeSecurityPolicyXRuleXRateLimitOptionsXExceedRedirectOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    target: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        target: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target", b"target", "type", b"type"]) -> None: ...

global___ComputeSecurityPolicyXRuleXRateLimitOptionsXExceedRedirectOptions = ComputeSecurityPolicyXRuleXRateLimitOptionsXExceedRedirectOptions

@typing_extensions.final
class ComputeSecurityPolicyXRuleXRateLimitOptionsXRateLimitThreshold(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    INTERVAL_SEC_FIELD_NUMBER: builtins.int
    count: builtins.float
    interval_sec: builtins.float
    def __init__(
        self,
        *,
        count: builtins.float = ...,
        interval_sec: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "interval_sec", b"interval_sec"]) -> None: ...

global___ComputeSecurityPolicyXRuleXRateLimitOptionsXRateLimitThreshold = ComputeSecurityPolicyXRuleXRateLimitOptionsXRateLimitThreshold

@typing_extensions.final
class ComputeSecurityPolicyXRuleXRateLimitOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BAN_DURATION_SEC_FIELD_NUMBER: builtins.int
    CONFORM_ACTION_FIELD_NUMBER: builtins.int
    ENFORCE_ON_KEY_FIELD_NUMBER: builtins.int
    ENFORCE_ON_KEY_NAME_FIELD_NUMBER: builtins.int
    EXCEED_ACTION_FIELD_NUMBER: builtins.int
    BAN_THRESHOLD_FIELD_NUMBER: builtins.int
    EXCEED_REDIRECT_OPTIONS_FIELD_NUMBER: builtins.int
    RATE_LIMIT_THRESHOLD_FIELD_NUMBER: builtins.int
    ban_duration_sec: builtins.float
    conform_action: builtins.str
    enforce_on_key: builtins.str
    enforce_on_key_name: builtins.str
    exceed_action: builtins.str
    @property
    def ban_threshold(self) -> global___ComputeSecurityPolicyXRuleXRateLimitOptionsXBanThreshold: ...
    @property
    def exceed_redirect_options(self) -> global___ComputeSecurityPolicyXRuleXRateLimitOptionsXExceedRedirectOptions: ...
    @property
    def rate_limit_threshold(self) -> global___ComputeSecurityPolicyXRuleXRateLimitOptionsXRateLimitThreshold: ...
    def __init__(
        self,
        *,
        ban_duration_sec: builtins.float = ...,
        conform_action: builtins.str = ...,
        enforce_on_key: builtins.str = ...,
        enforce_on_key_name: builtins.str = ...,
        exceed_action: builtins.str = ...,
        ban_threshold: global___ComputeSecurityPolicyXRuleXRateLimitOptionsXBanThreshold | None = ...,
        exceed_redirect_options: global___ComputeSecurityPolicyXRuleXRateLimitOptionsXExceedRedirectOptions | None = ...,
        rate_limit_threshold: global___ComputeSecurityPolicyXRuleXRateLimitOptionsXRateLimitThreshold | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ban_threshold", b"ban_threshold", "exceed_redirect_options", b"exceed_redirect_options", "rate_limit_threshold", b"rate_limit_threshold"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ban_duration_sec", b"ban_duration_sec", "ban_threshold", b"ban_threshold", "conform_action", b"conform_action", "enforce_on_key", b"enforce_on_key", "enforce_on_key_name", b"enforce_on_key_name", "exceed_action", b"exceed_action", "exceed_redirect_options", b"exceed_redirect_options", "rate_limit_threshold", b"rate_limit_threshold"]) -> None: ...

global___ComputeSecurityPolicyXRuleXRateLimitOptions = ComputeSecurityPolicyXRuleXRateLimitOptions

@typing_extensions.final
class ComputeSecurityPolicyXRuleXRedirectOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    target: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        target: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target", b"target", "type", b"type"]) -> None: ...

global___ComputeSecurityPolicyXRuleXRedirectOptions = ComputeSecurityPolicyXRuleXRedirectOptions

@typing_extensions.final
class ComputeSecurityPolicyXRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PREVIEW_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    MATCH_FIELD_NUMBER: builtins.int
    RATE_LIMIT_OPTIONS_FIELD_NUMBER: builtins.int
    REDIRECT_OPTIONS_FIELD_NUMBER: builtins.int
    action: builtins.str
    description: builtins.str
    preview: builtins.bool
    priority: builtins.float
    @property
    def match(self) -> global___ComputeSecurityPolicyXRuleXMatch: ...
    @property
    def rate_limit_options(self) -> global___ComputeSecurityPolicyXRuleXRateLimitOptions: ...
    @property
    def redirect_options(self) -> global___ComputeSecurityPolicyXRuleXRedirectOptions: ...
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        description: builtins.str = ...,
        preview: builtins.bool = ...,
        priority: builtins.float = ...,
        match: global___ComputeSecurityPolicyXRuleXMatch | None = ...,
        rate_limit_options: global___ComputeSecurityPolicyXRuleXRateLimitOptions | None = ...,
        redirect_options: global___ComputeSecurityPolicyXRuleXRedirectOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["match", b"match", "rate_limit_options", b"rate_limit_options", "redirect_options", b"redirect_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "description", b"description", "match", b"match", "preview", b"preview", "priority", b"priority", "rate_limit_options", b"rate_limit_options", "redirect_options", b"redirect_options"]) -> None: ...

global___ComputeSecurityPolicyXRule = ComputeSecurityPolicyXRule

@typing_extensions.final
class ComputeSecurityPolicyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeSecurityPolicyXTimeouts = ComputeSecurityPolicyXTimeouts

@typing_extensions.final
class ComputeSecurityPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ADAPTIVE_PROTECTION_CONFIG_FIELD_NUMBER: builtins.int
    ADVANCED_OPTIONS_CONFIG_FIELD_NUMBER: builtins.int
    RULE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    fingerprint: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    type: builtins.str
    @property
    def adaptive_protection_config(self) -> global___ComputeSecurityPolicyXAdaptiveProtectionConfig: ...
    @property
    def advanced_options_config(self) -> global___ComputeSecurityPolicyXAdvancedOptionsConfig: ...
    @property
    def rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeSecurityPolicyXRule]: ...
    @property
    def timeouts(self) -> global___ComputeSecurityPolicyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        fingerprint: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        type: builtins.str = ...,
        adaptive_protection_config: global___ComputeSecurityPolicyXAdaptiveProtectionConfig | None = ...,
        advanced_options_config: global___ComputeSecurityPolicyXAdvancedOptionsConfig | None = ...,
        rule: collections.abc.Iterable[global___ComputeSecurityPolicyXRule] | None = ...,
        timeouts: global___ComputeSecurityPolicyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["adaptive_protection_config", b"adaptive_protection_config", "advanced_options_config", b"advanced_options_config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["adaptive_protection_config", b"adaptive_protection_config", "advanced_options_config", b"advanced_options_config", "description", b"description", "fingerprint", b"fingerprint", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "rule", b"rule", "self_link", b"self_link", "timeouts", b"timeouts", "type", b"type"]) -> None: ...

global___ComputeSecurityPolicy = ComputeSecurityPolicy



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ServerProtocol(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___ServerProtocol = ServerProtocol

@typing_extensions.final
class ServerIdentityProviderDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INVOCATION_ROLE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    invocation_role: builtins.str
    url: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        invocation_role: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["invocation_role", b"invocation_role", "resource_info", b"resource_info", "url", b"url"]) -> None: ...

global___ServerIdentityProviderDetails = ServerIdentityProviderDetails

@typing_extensions.final
class ServerEndpointDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ADDRESS_ALLOCATION_IDS_FIELD_NUMBER: builtins.int
    VPC_ID_FIELD_NUMBER: builtins.int
    VPC_ENDPOINT_ID_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def address_allocation_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    vpc_id: builtins.str
    vpc_endpoint_id: builtins.str
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        address_allocation_ids: collections.abc.Iterable[builtins.str] | None = ...,
        vpc_id: builtins.str = ...,
        vpc_endpoint_id: builtins.str = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address_allocation_ids", b"address_allocation_ids", "resource_info", b"resource_info", "subnet_ids", b"subnet_ids", "vpc_endpoint_id", b"vpc_endpoint_id", "vpc_id", b"vpc_id"]) -> None: ...

global___ServerEndpointDetails = ServerEndpointDetails

@typing_extensions.final
class Server(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LOGGING_ROLE_FIELD_NUMBER: builtins.int
    PROTOCOLS_FIELD_NUMBER: builtins.int
    IDENTITY_PROVIDER_DETAILS_FIELD_NUMBER: builtins.int
    ENDPOINT_TYPE_FIELD_NUMBER: builtins.int
    SECURITY_POLICY_NAME_FIELD_NUMBER: builtins.int
    ENDPOINT_DETAILS_FIELD_NUMBER: builtins.int
    IDENTITY_PROVIDER_TYPE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    CERTIFICATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    logging_role: builtins.str
    @property
    def protocols(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServerProtocol]: ...
    @property
    def identity_provider_details(self) -> global___ServerIdentityProviderDetails: ...
    endpoint_type: builtins.str
    security_policy_name: builtins.str
    @property
    def endpoint_details(self) -> global___ServerEndpointDetails: ...
    identity_provider_type: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    certificate: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        logging_role: builtins.str = ...,
        protocols: collections.abc.Iterable[global___ServerProtocol] | None = ...,
        identity_provider_details: global___ServerIdentityProviderDetails | None = ...,
        endpoint_type: builtins.str = ...,
        security_policy_name: builtins.str = ...,
        endpoint_details: global___ServerEndpointDetails | None = ...,
        identity_provider_type: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        certificate: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["endpoint_details", b"endpoint_details", "identity_provider_details", b"identity_provider_details", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate", b"certificate", "endpoint_details", b"endpoint_details", "endpoint_type", b"endpoint_type", "identity_provider_details", b"identity_provider_details", "identity_provider_type", b"identity_provider_type", "logging_role", b"logging_role", "protocols", b"protocols", "resource_info", b"resource_info", "security_policy_name", b"security_policy_name", "tags", b"tags"]) -> None: ...

global___Server = Server

@typing_extensions.final
class Transfer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVER_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    @property
    def server(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Server]: ...
    @property
    def user(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___User]: ...
    def __init__(
        self,
        *,
        server: collections.abc.Iterable[global___Server] | None = ...,
        user: collections.abc.Iterable[global___User] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["server", b"server", "user", b"user"]) -> None: ...

global___Transfer = Transfer

@typing_extensions.final
class UserHomeDirectoryMapEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENTRY_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    entry: builtins.str
    target: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        entry: builtins.str = ...,
        target: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entry", b"entry", "resource_info", b"resource_info", "target", b"target"]) -> None: ...

global___UserHomeDirectoryMapEntry = UserHomeDirectoryMapEntry

@typing_extensions.final
class UserSshPublicKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___UserSshPublicKey = UserSshPublicKey

@typing_extensions.final
class User(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    POLICY_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    HOME_DIRECTORY_FIELD_NUMBER: builtins.int
    HOME_DIRECTORY_TYPE_FIELD_NUMBER: builtins.int
    SERVER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    HOME_DIRECTORY_MAPPINGS_FIELD_NUMBER: builtins.int
    SSH_PUBLIC_KEYS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    policy: builtins.str
    role: builtins.str
    home_directory: builtins.str
    home_directory_type: builtins.str
    server_id: builtins.str
    user_name: builtins.str
    @property
    def home_directory_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UserHomeDirectoryMapEntry]: ...
    @property
    def ssh_public_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UserSshPublicKey]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        policy: builtins.str = ...,
        role: builtins.str = ...,
        home_directory: builtins.str = ...,
        home_directory_type: builtins.str = ...,
        server_id: builtins.str = ...,
        user_name: builtins.str = ...,
        home_directory_mappings: collections.abc.Iterable[global___UserHomeDirectoryMapEntry] | None = ...,
        ssh_public_keys: collections.abc.Iterable[global___UserSshPublicKey] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["home_directory", b"home_directory", "home_directory_mappings", b"home_directory_mappings", "home_directory_type", b"home_directory_type", "policy", b"policy", "resource_info", b"resource_info", "role", b"role", "server_id", b"server_id", "ssh_public_keys", b"ssh_public_keys", "tags", b"tags", "user_name", b"user_name"]) -> None: ...

global___User = User



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Elastic(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MONITORS_FIELD_NUMBER: builtins.int
    @property
    def monitors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Monitors]: ...
    def __init__(
        self,
        *,
        monitors: collections.abc.Iterable[global___Monitors] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["monitors", b"monitors"]) -> None: ...

global___Microsoft_Elastic = Microsoft_Elastic

@typing_extensions.final
class MonitorsTagRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LOG_RULES_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def log_rules(self) -> global___LogRules: ...
    provisioning_state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        log_rules: global___LogRules | None = ...,
        provisioning_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["log_rules", b"log_rules", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["log_rules", b"log_rules", "name", b"name", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info"]) -> None: ...

global___MonitorsTagRules = MonitorsTagRules

@typing_extensions.final
class LogRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILTERING_TAGS_FIELD_NUMBER: builtins.int
    SEND_AAD_LOGS_FIELD_NUMBER: builtins.int
    SEND_ACTIVITY_LOGS_FIELD_NUMBER: builtins.int
    SEND_SUBSCRIPTION_LOGS_FIELD_NUMBER: builtins.int
    @property
    def filtering_tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FilteringTag]: ...
    send_aad_logs: builtins.bool
    send_activity_logs: builtins.bool
    send_subscription_logs: builtins.bool
    def __init__(
        self,
        *,
        filtering_tags: collections.abc.Iterable[global___FilteringTag] | None = ...,
        send_aad_logs: builtins.bool = ...,
        send_activity_logs: builtins.bool = ...,
        send_subscription_logs: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["filtering_tags", b"filtering_tags", "send_aad_logs", b"send_aad_logs", "send_activity_logs", b"send_activity_logs", "send_subscription_logs", b"send_subscription_logs"]) -> None: ...

global___LogRules = LogRules

@typing_extensions.final
class FilteringTag(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    action: builtins.str
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "name", b"name", "value", b"value"]) -> None: ...

global___FilteringTag = FilteringTag

@typing_extensions.final
class Monitors(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ELASTIC_PROPERTIES_FIELD_NUMBER: builtins.int
    LIFTR_RESOURCE_CATEGORY_FIELD_NUMBER: builtins.int
    MONITORING_STATUS_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    USER_INFO_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    MONITORS_TAG_RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___IdentityProperties: ...
    location: builtins.str
    name: builtins.str
    @property
    def elastic_properties(self) -> global___ElasticProperties: ...
    liftr_resource_category: builtins.str
    monitoring_status: builtins.str
    provisioning_state: builtins.str
    @property
    def user_info(self) -> global___UserInfo: ...
    version: builtins.str
    @property
    def sku(self) -> global___ResourceSku: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def monitors_tag_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MonitorsTagRules]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___IdentityProperties | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        elastic_properties: global___ElasticProperties | None = ...,
        liftr_resource_category: builtins.str = ...,
        monitoring_status: builtins.str = ...,
        provisioning_state: builtins.str = ...,
        user_info: global___UserInfo | None = ...,
        version: builtins.str = ...,
        sku: global___ResourceSku | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        monitors_tag_rules: collections.abc.Iterable[global___MonitorsTagRules] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["elastic_properties", b"elastic_properties", "identity", b"identity", "resource_info", b"resource_info", "sku", b"sku", "user_info", b"user_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["elastic_properties", b"elastic_properties", "identity", b"identity", "liftr_resource_category", b"liftr_resource_category", "location", b"location", "monitoring_status", b"monitoring_status", "monitors_tag_rules", b"monitors_tag_rules", "name", b"name", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info", "sku", b"sku", "tags", b"tags", "user_info", b"user_info", "version", b"version"]) -> None: ...

global___Monitors = Monitors

@typing_extensions.final
class ResourceSku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___ResourceSku = ResourceSku

@typing_extensions.final
class UserInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPANY_INFO_FIELD_NUMBER: builtins.int
    COMPANY_NAME_FIELD_NUMBER: builtins.int
    EMAIL_ADDRESS_FIELD_NUMBER: builtins.int
    FIRST_NAME_FIELD_NUMBER: builtins.int
    LAST_NAME_FIELD_NUMBER: builtins.int
    @property
    def company_info(self) -> global___CompanyInfo: ...
    company_name: builtins.str
    email_address: builtins.str
    first_name: builtins.str
    last_name: builtins.str
    def __init__(
        self,
        *,
        company_info: global___CompanyInfo | None = ...,
        company_name: builtins.str = ...,
        email_address: builtins.str = ...,
        first_name: builtins.str = ...,
        last_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["company_info", b"company_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["company_info", b"company_info", "company_name", b"company_name", "email_address", b"email_address", "first_name", b"first_name", "last_name", b"last_name"]) -> None: ...

global___UserInfo = UserInfo

@typing_extensions.final
class CompanyInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUSINESS_FIELD_NUMBER: builtins.int
    COUNTRY_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    EMPLOYEES_NUMBER_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    business: builtins.str
    country: builtins.str
    domain: builtins.str
    employees_number: builtins.str
    state: builtins.str
    def __init__(
        self,
        *,
        business: builtins.str = ...,
        country: builtins.str = ...,
        domain: builtins.str = ...,
        employees_number: builtins.str = ...,
        state: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["business", b"business", "country", b"country", "domain", b"domain", "employees_number", b"employees_number", "state", b"state"]) -> None: ...

global___CompanyInfo = CompanyInfo

@typing_extensions.final
class ElasticProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ELASTIC_CLOUD_DEPLOYMENT_FIELD_NUMBER: builtins.int
    ELASTIC_CLOUD_USER_FIELD_NUMBER: builtins.int
    @property
    def elastic_cloud_deployment(self) -> global___ElasticCloudDeployment: ...
    @property
    def elastic_cloud_user(self) -> global___ElasticCloudUser: ...
    def __init__(
        self,
        *,
        elastic_cloud_deployment: global___ElasticCloudDeployment | None = ...,
        elastic_cloud_user: global___ElasticCloudUser | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["elastic_cloud_deployment", b"elastic_cloud_deployment", "elastic_cloud_user", b"elastic_cloud_user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["elastic_cloud_deployment", b"elastic_cloud_deployment", "elastic_cloud_user", b"elastic_cloud_user"]) -> None: ...

global___ElasticProperties = ElasticProperties

@typing_extensions.final
class ElasticCloudUser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___ElasticCloudUser = ElasticCloudUser

@typing_extensions.final
class ElasticCloudDeployment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___ElasticCloudDeployment = ElasticCloudDeployment

@typing_extensions.final
class IdentityProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

global___IdentityProperties = IdentityProperties



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Network_networkSecurityGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    NETWORK_SECURITY_GROUPS_SECURITY_RULES_FIELD_NUMBER: builtins.int
    @property
    def network_security_groups(self) -> global___NetworkSecurityGroups: ...
    @property
    def network_security_groups_security_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkSecurityGroupsSecurityRules]: ...
    def __init__(
        self,
        *,
        network_security_groups: global___NetworkSecurityGroups | None = ...,
        network_security_groups_security_rules: collections.abc.Iterable[global___NetworkSecurityGroupsSecurityRules] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_security_groups", b"network_security_groups"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["network_security_groups", b"network_security_groups", "network_security_groups_security_rules", b"network_security_groups_security_rules"]) -> None: ...

global___Microsoft_Network_networkSecurityGroups = Microsoft_Network_networkSecurityGroups

@typing_extensions.final
class NetworkSecurityGroupsSecurityRules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    SOURCE_PORT_RANGE_FIELD_NUMBER: builtins.int
    DESTINATION_PORT_RANGE_FIELD_NUMBER: builtins.int
    SOURCE_ADDRESS_PREFIX_FIELD_NUMBER: builtins.int
    SOURCE_ADDRESS_PREFIXES_FIELD_NUMBER: builtins.int
    SOURCE_APPLICATION_SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    DESTINATION_ADDRESS_PREFIX_FIELD_NUMBER: builtins.int
    DESTINATION_ADDRESS_PREFIXES_FIELD_NUMBER: builtins.int
    DESTINATION_APPLICATION_SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    SOURCE_PORT_RANGES_FIELD_NUMBER: builtins.int
    DESTINATION_PORT_RANGES_FIELD_NUMBER: builtins.int
    ACCESS_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    description: builtins.str
    protocol: builtins.str
    source_port_range: builtins.str
    destination_port_range: builtins.str
    source_address_prefix: builtins.str
    @property
    def source_address_prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def source_application_security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    destination_address_prefix: builtins.str
    @property
    def destination_address_prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def destination_application_security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def source_port_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def destination_port_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    access: builtins.str
    priority: builtins.int
    direction: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        protocol: builtins.str = ...,
        source_port_range: builtins.str = ...,
        destination_port_range: builtins.str = ...,
        source_address_prefix: builtins.str = ...,
        source_address_prefixes: collections.abc.Iterable[builtins.str] | None = ...,
        source_application_security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        destination_address_prefix: builtins.str = ...,
        destination_address_prefixes: collections.abc.Iterable[builtins.str] | None = ...,
        destination_application_security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        source_port_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        destination_port_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        access: builtins.str = ...,
        priority: builtins.int = ...,
        direction: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access", b"access", "description", b"description", "destination_address_prefix", b"destination_address_prefix", "destination_address_prefixes", b"destination_address_prefixes", "destination_application_security_groups", b"destination_application_security_groups", "destination_port_range", b"destination_port_range", "destination_port_ranges", b"destination_port_ranges", "direction", b"direction", "name", b"name", "priority", b"priority", "protocol", b"protocol", "resource_info", b"resource_info", "source_address_prefix", b"source_address_prefix", "source_address_prefixes", b"source_address_prefixes", "source_application_security_groups", b"source_application_security_groups", "source_port_range", b"source_port_range", "source_port_ranges", b"source_port_ranges"]) -> None: ...

global___NetworkSecurityGroupsSecurityRules = NetworkSecurityGroupsSecurityRules

@typing_extensions.final
class NetworkSecurityGroups(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    SECURITY_RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    location: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def security_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SecurityRule]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        location: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        security_rules: collections.abc.Iterable[global___SecurityRule] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "name", b"name", "resource_info", b"resource_info", "security_rules", b"security_rules", "tags", b"tags"]) -> None: ...

global___NetworkSecurityGroups = NetworkSecurityGroups

@typing_extensions.final
class SecurityRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    SOURCE_PORT_RANGE_FIELD_NUMBER: builtins.int
    DESTINATION_PORT_RANGE_FIELD_NUMBER: builtins.int
    SOURCE_ADDRESS_PREFIX_FIELD_NUMBER: builtins.int
    SOURCE_ADDRESS_PREFIXES_FIELD_NUMBER: builtins.int
    SOURCE_APPLICATION_SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    DESTINATION_ADDRESS_PREFIX_FIELD_NUMBER: builtins.int
    DESTINATION_ADDRESS_PREFIXES_FIELD_NUMBER: builtins.int
    DESTINATION_APPLICATION_SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    SOURCE_PORT_RANGES_FIELD_NUMBER: builtins.int
    DESTINATION_PORT_RANGES_FIELD_NUMBER: builtins.int
    ACCESS_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    description: builtins.str
    protocol: builtins.str
    source_port_range: builtins.str
    destination_port_range: builtins.str
    source_address_prefix: builtins.str
    @property
    def source_address_prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def source_application_security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    destination_address_prefix: builtins.str
    @property
    def destination_address_prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def destination_application_security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def source_port_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def destination_port_ranges(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    access: builtins.str
    priority: builtins.int
    direction: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        protocol: builtins.str = ...,
        source_port_range: builtins.str = ...,
        destination_port_range: builtins.str = ...,
        source_address_prefix: builtins.str = ...,
        source_address_prefixes: collections.abc.Iterable[builtins.str] | None = ...,
        source_application_security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        destination_address_prefix: builtins.str = ...,
        destination_address_prefixes: collections.abc.Iterable[builtins.str] | None = ...,
        destination_application_security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        source_port_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        destination_port_ranges: collections.abc.Iterable[builtins.str] | None = ...,
        access: builtins.str = ...,
        priority: builtins.int = ...,
        direction: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access", b"access", "description", b"description", "destination_address_prefix", b"destination_address_prefix", "destination_address_prefixes", b"destination_address_prefixes", "destination_application_security_groups", b"destination_application_security_groups", "destination_port_range", b"destination_port_range", "destination_port_ranges", b"destination_port_ranges", "direction", b"direction", "name", b"name", "priority", b"priority", "protocol", b"protocol", "source_address_prefix", b"source_address_prefix", "source_address_prefixes", b"source_address_prefixes", "source_application_security_groups", b"source_application_security_groups", "source_port_range", b"source_port_range", "source_port_ranges", b"source_port_ranges"]) -> None: ...

global___SecurityRule = SecurityRule



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network_networksecuritygroups.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9azure/azure_microsoft_network_networksecuritygroups.proto\x12\x39oak9.tython.azure.microsoft_network_networksecuritygroups\x1a\x13shared/shared.proto\"\xac\x02\n\'Microsoft_Network_networkSecurityGroups\x12q\n\x17network_security_groups\x18\x01 \x01(\x0b\x32P.oak9.tython.azure.microsoft_network_networksecuritygroups.NetworkSecurityGroups\x12\x8d\x01\n&network_security_groups_security_rules\x18\x02 \x03(\x0b\x32].oak9.tython.azure.microsoft_network_networksecuritygroups.NetworkSecurityGroupsSecurityRules\"\xa6\x04\n\"NetworkSecurityGroupsSecurityRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08protocol\x18\x04 \x01(\t\x12\x19\n\x11source_port_range\x18\x05 \x01(\t\x12\x1e\n\x16\x64\x65stination_port_range\x18\x06 \x01(\t\x12\x1d\n\x15source_address_prefix\x18\x07 \x01(\t\x12\x1f\n\x17source_address_prefixes\x18\x08 \x03(\t\x12*\n\"source_application_security_groups\x18\t \x03(\t\x12\"\n\x1a\x64\x65stination_address_prefix\x18\n \x01(\t\x12$\n\x1c\x64\x65stination_address_prefixes\x18\x0b \x03(\t\x12/\n\'destination_application_security_groups\x18\x0c \x03(\t\x12\x1a\n\x12source_port_ranges\x18\r \x03(\t\x12\x1f\n\x17\x64\x65stination_port_ranges\x18\x0e \x03(\t\x12\x0e\n\x06\x61\x63\x63\x65ss\x18\x0f \x01(\t\x12\x10\n\x08priority\x18\x10 \x01(\x05\x12\x11\n\tdirection\x18\x11 \x01(\t\"\xe8\x02\n\x15NetworkSecurityGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12h\n\x04tags\x18\x04 \x03(\x0b\x32Z.oak9.tython.azure.microsoft_network_networksecuritygroups.NetworkSecurityGroups.TagsEntry\x12_\n\x0esecurity_rules\x18\x05 \x03(\x0b\x32G.oak9.tython.azure.microsoft_network_networksecuritygroups.SecurityRule\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd7\x03\n\x0cSecurityRule\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x10\n\x08protocol\x18\x02 \x01(\t\x12\x19\n\x11source_port_range\x18\x03 \x01(\t\x12\x1e\n\x16\x64\x65stination_port_range\x18\x04 \x01(\t\x12\x1d\n\x15source_address_prefix\x18\x05 \x01(\t\x12\x1f\n\x17source_address_prefixes\x18\x06 \x03(\t\x12*\n\"source_application_security_groups\x18\x07 \x03(\t\x12\"\n\x1a\x64\x65stination_address_prefix\x18\x08 \x01(\t\x12$\n\x1c\x64\x65stination_address_prefixes\x18\t \x03(\t\x12/\n\'destination_application_security_groups\x18\n \x03(\t\x12\x1a\n\x12source_port_ranges\x18\x0b \x03(\t\x12\x1f\n\x17\x64\x65stination_port_ranges\x18\x0c \x03(\t\x12\x0e\n\x06\x61\x63\x63\x65ss\x18\r \x01(\t\x12\x10\n\x08priority\x18\x0e \x01(\x05\x12\x11\n\tdirection\x18\x0f \x01(\t\x12\x0c\n\x04name\x18\x10 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_networksecuritygroups_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NETWORKSECURITYGROUPS_TAGSENTRY._options = None
  _NETWORKSECURITYGROUPS_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK_NETWORKSECURITYGROUPS._serialized_start=142
  _MICROSOFT_NETWORK_NETWORKSECURITYGROUPS._serialized_end=442
  _NETWORKSECURITYGROUPSSECURITYRULES._serialized_start=445
  _NETWORKSECURITYGROUPSSECURITYRULES._serialized_end=995
  _NETWORKSECURITYGROUPS._serialized_start=998
  _NETWORKSECURITYGROUPS._serialized_end=1358
  _NETWORKSECURITYGROUPS_TAGSENTRY._serialized_start=1315
  _NETWORKSECURITYGROUPS_TAGSENTRY._serialized_end=1358
  _SECURITYRULE._serialized_start=1361
  _SECURITYRULE._serialized_end=1832
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class SqlDatabaseXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___SqlDatabaseXTimeouts = SqlDatabaseXTimeouts

@typing_extensions.final
class SqlDatabase(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHARSET_FIELD_NUMBER: builtins.int
    COLLATION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    charset: builtins.str
    collation: builtins.str
    id: builtins.str
    instance: builtins.str
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    @property
    def timeouts(self) -> global___SqlDatabaseXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        charset: builtins.str = ...,
        collation: builtins.str = ...,
        id: builtins.str = ...,
        instance: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        timeouts: global___SqlDatabaseXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["charset", b"charset", "collation", b"collation", "id", b"id", "instance", b"instance", "name", b"name", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts"]) -> None: ...

global___SqlDatabase = SqlDatabase

@typing_extensions.final
class SqlDatabaseInstanceXReplicaConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CA_CERTIFICATE_FIELD_NUMBER: builtins.int
    CLIENT_CERTIFICATE_FIELD_NUMBER: builtins.int
    CLIENT_KEY_FIELD_NUMBER: builtins.int
    CONNECT_RETRY_INTERVAL_FIELD_NUMBER: builtins.int
    DUMP_FILE_PATH_FIELD_NUMBER: builtins.int
    FAILOVER_TARGET_FIELD_NUMBER: builtins.int
    MASTER_HEARTBEAT_PERIOD_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    SSL_CIPHER_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    VERIFY_SERVER_CERTIFICATE_FIELD_NUMBER: builtins.int
    ca_certificate: builtins.str
    client_certificate: builtins.str
    client_key: builtins.str
    connect_retry_interval: builtins.float
    dump_file_path: builtins.str
    failover_target: builtins.bool
    master_heartbeat_period: builtins.float
    password: builtins.str
    ssl_cipher: builtins.str
    username: builtins.str
    verify_server_certificate: builtins.bool
    def __init__(
        self,
        *,
        ca_certificate: builtins.str = ...,
        client_certificate: builtins.str = ...,
        client_key: builtins.str = ...,
        connect_retry_interval: builtins.float = ...,
        dump_file_path: builtins.str = ...,
        failover_target: builtins.bool = ...,
        master_heartbeat_period: builtins.float = ...,
        password: builtins.str = ...,
        ssl_cipher: builtins.str = ...,
        username: builtins.str = ...,
        verify_server_certificate: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ca_certificate", b"ca_certificate", "client_certificate", b"client_certificate", "client_key", b"client_key", "connect_retry_interval", b"connect_retry_interval", "dump_file_path", b"dump_file_path", "failover_target", b"failover_target", "master_heartbeat_period", b"master_heartbeat_period", "password", b"password", "ssl_cipher", b"ssl_cipher", "username", b"username", "verify_server_certificate", b"verify_server_certificate"]) -> None: ...

global___SqlDatabaseInstanceXReplicaConfiguration = SqlDatabaseInstanceXReplicaConfiguration

@typing_extensions.final
class SqlDatabaseInstanceXRestoreBackupContext(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKUP_RUN_ID_FIELD_NUMBER: builtins.int
    INSTANCE_ID_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    backup_run_id: builtins.float
    instance_id: builtins.str
    project: builtins.str
    def __init__(
        self,
        *,
        backup_run_id: builtins.float = ...,
        instance_id: builtins.str = ...,
        project: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_run_id", b"backup_run_id", "instance_id", b"instance_id", "project", b"project"]) -> None: ...

global___SqlDatabaseInstanceXRestoreBackupContext = SqlDatabaseInstanceXRestoreBackupContext

@typing_extensions.final
class SqlDatabaseInstanceXSettingsXActiveDirectoryConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_FIELD_NUMBER: builtins.int
    domain: builtins.str
    def __init__(
        self,
        *,
        domain: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain", b"domain"]) -> None: ...

global___SqlDatabaseInstanceXSettingsXActiveDirectoryConfig = SqlDatabaseInstanceXSettingsXActiveDirectoryConfig

@typing_extensions.final
class SqlDatabaseInstanceXSettingsXBackupConfigurationXBackupRetentionSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RETAINED_BACKUPS_FIELD_NUMBER: builtins.int
    RETENTION_UNIT_FIELD_NUMBER: builtins.int
    retained_backups: builtins.float
    retention_unit: builtins.str
    def __init__(
        self,
        *,
        retained_backups: builtins.float = ...,
        retention_unit: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["retained_backups", b"retained_backups", "retention_unit", b"retention_unit"]) -> None: ...

global___SqlDatabaseInstanceXSettingsXBackupConfigurationXBackupRetentionSettings = SqlDatabaseInstanceXSettingsXBackupConfigurationXBackupRetentionSettings

@typing_extensions.final
class SqlDatabaseInstanceXSettingsXBackupConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BINARY_LOG_ENABLED_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    POINT_IN_TIME_RECOVERY_ENABLED_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    TRANSACTION_LOG_RETENTION_DAYS_FIELD_NUMBER: builtins.int
    BACKUP_RETENTION_SETTINGS_FIELD_NUMBER: builtins.int
    binary_log_enabled: builtins.bool
    enabled: builtins.bool
    location: builtins.str
    point_in_time_recovery_enabled: builtins.bool
    start_time: builtins.str
    transaction_log_retention_days: builtins.float
    @property
    def backup_retention_settings(self) -> global___SqlDatabaseInstanceXSettingsXBackupConfigurationXBackupRetentionSettings: ...
    def __init__(
        self,
        *,
        binary_log_enabled: builtins.bool = ...,
        enabled: builtins.bool = ...,
        location: builtins.str = ...,
        point_in_time_recovery_enabled: builtins.bool = ...,
        start_time: builtins.str = ...,
        transaction_log_retention_days: builtins.float = ...,
        backup_retention_settings: global___SqlDatabaseInstanceXSettingsXBackupConfigurationXBackupRetentionSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backup_retention_settings", b"backup_retention_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_retention_settings", b"backup_retention_settings", "binary_log_enabled", b"binary_log_enabled", "enabled", b"enabled", "location", b"location", "point_in_time_recovery_enabled", b"point_in_time_recovery_enabled", "start_time", b"start_time", "transaction_log_retention_days", b"transaction_log_retention_days"]) -> None: ...

global___SqlDatabaseInstanceXSettingsXBackupConfiguration = SqlDatabaseInstanceXSettingsXBackupConfiguration

@typing_extensions.final
class SqlDatabaseInstanceXSettingsXDatabaseFlags(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "value", b"value"]) -> None: ...

global___SqlDatabaseInstanceXSettingsXDatabaseFlags = SqlDatabaseInstanceXSettingsXDatabaseFlags

@typing_extensions.final
class SqlDatabaseInstanceXSettingsXInsightsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_INSIGHTS_ENABLED_FIELD_NUMBER: builtins.int
    QUERY_STRING_LENGTH_FIELD_NUMBER: builtins.int
    RECORD_APPLICATION_TAGS_FIELD_NUMBER: builtins.int
    RECORD_CLIENT_ADDRESS_FIELD_NUMBER: builtins.int
    query_insights_enabled: builtins.bool
    query_string_length: builtins.float
    record_application_tags: builtins.bool
    record_client_address: builtins.bool
    def __init__(
        self,
        *,
        query_insights_enabled: builtins.bool = ...,
        query_string_length: builtins.float = ...,
        record_application_tags: builtins.bool = ...,
        record_client_address: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["query_insights_enabled", b"query_insights_enabled", "query_string_length", b"query_string_length", "record_application_tags", b"record_application_tags", "record_client_address", b"record_client_address"]) -> None: ...

global___SqlDatabaseInstanceXSettingsXInsightsConfig = SqlDatabaseInstanceXSettingsXInsightsConfig

@typing_extensions.final
class SqlDatabaseInstanceXSettingsXIpConfigurationXAuthorizedNetworks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPIRATION_TIME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    expiration_time: builtins.str
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        expiration_time: builtins.str = ...,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["expiration_time", b"expiration_time", "name", b"name", "value", b"value"]) -> None: ...

global___SqlDatabaseInstanceXSettingsXIpConfigurationXAuthorizedNetworks = SqlDatabaseInstanceXSettingsXIpConfigurationXAuthorizedNetworks

@typing_extensions.final
class SqlDatabaseInstanceXSettingsXIpConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOCATED_IP_RANGE_FIELD_NUMBER: builtins.int
    IPV4_ENABLED_FIELD_NUMBER: builtins.int
    PRIVATE_NETWORK_FIELD_NUMBER: builtins.int
    REQUIRE_SSL_FIELD_NUMBER: builtins.int
    AUTHORIZED_NETWORKS_FIELD_NUMBER: builtins.int
    allocated_ip_range: builtins.str
    ipv4_enabled: builtins.bool
    private_network: builtins.str
    require_ssl: builtins.bool
    @property
    def authorized_networks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SqlDatabaseInstanceXSettingsXIpConfigurationXAuthorizedNetworks]: ...
    def __init__(
        self,
        *,
        allocated_ip_range: builtins.str = ...,
        ipv4_enabled: builtins.bool = ...,
        private_network: builtins.str = ...,
        require_ssl: builtins.bool = ...,
        authorized_networks: collections.abc.Iterable[global___SqlDatabaseInstanceXSettingsXIpConfigurationXAuthorizedNetworks] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allocated_ip_range", b"allocated_ip_range", "authorized_networks", b"authorized_networks", "ipv4_enabled", b"ipv4_enabled", "private_network", b"private_network", "require_ssl", b"require_ssl"]) -> None: ...

global___SqlDatabaseInstanceXSettingsXIpConfiguration = SqlDatabaseInstanceXSettingsXIpConfiguration

@typing_extensions.final
class SqlDatabaseInstanceXSettingsXLocationPreference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLLOW_GAE_APPLICATION_FIELD_NUMBER: builtins.int
    SECONDARY_ZONE_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    follow_gae_application: builtins.str
    secondary_zone: builtins.str
    zone: builtins.str
    def __init__(
        self,
        *,
        follow_gae_application: builtins.str = ...,
        secondary_zone: builtins.str = ...,
        zone: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["follow_gae_application", b"follow_gae_application", "secondary_zone", b"secondary_zone", "zone", b"zone"]) -> None: ...

global___SqlDatabaseInstanceXSettingsXLocationPreference = SqlDatabaseInstanceXSettingsXLocationPreference

@typing_extensions.final
class SqlDatabaseInstanceXSettingsXMaintenanceWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAY_FIELD_NUMBER: builtins.int
    HOUR_FIELD_NUMBER: builtins.int
    UPDATE_TRACK_FIELD_NUMBER: builtins.int
    day: builtins.float
    hour: builtins.float
    update_track: builtins.str
    def __init__(
        self,
        *,
        day: builtins.float = ...,
        hour: builtins.float = ...,
        update_track: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["day", b"day", "hour", b"hour", "update_track", b"update_track"]) -> None: ...

global___SqlDatabaseInstanceXSettingsXMaintenanceWindow = SqlDatabaseInstanceXSettingsXMaintenanceWindow

@typing_extensions.final
class SqlDatabaseInstanceXSettingsXSqlServerAuditConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    RETENTION_INTERVAL_FIELD_NUMBER: builtins.int
    UPLOAD_INTERVAL_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    retention_interval: builtins.str
    upload_interval: builtins.str
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        retention_interval: builtins.str = ...,
        upload_interval: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "retention_interval", b"retention_interval", "upload_interval", b"upload_interval"]) -> None: ...

global___SqlDatabaseInstanceXSettingsXSqlServerAuditConfig = SqlDatabaseInstanceXSettingsXSqlServerAuditConfig

@typing_extensions.final
class SqlDatabaseInstanceXSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserLabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ACTIVATION_POLICY_FIELD_NUMBER: builtins.int
    AVAILABILITY_TYPE_FIELD_NUMBER: builtins.int
    COLLATION_FIELD_NUMBER: builtins.int
    DISK_AUTORESIZE_FIELD_NUMBER: builtins.int
    DISK_AUTORESIZE_LIMIT_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    DISK_TYPE_FIELD_NUMBER: builtins.int
    PRICING_PLAN_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    USER_LABELS_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    ACTIVE_DIRECTORY_CONFIG_FIELD_NUMBER: builtins.int
    BACKUP_CONFIGURATION_FIELD_NUMBER: builtins.int
    DATABASE_FLAGS_FIELD_NUMBER: builtins.int
    INSIGHTS_CONFIG_FIELD_NUMBER: builtins.int
    IP_CONFIGURATION_FIELD_NUMBER: builtins.int
    LOCATION_PREFERENCE_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    SQL_SERVER_AUDIT_CONFIG_FIELD_NUMBER: builtins.int
    activation_policy: builtins.str
    availability_type: builtins.str
    collation: builtins.str
    disk_autoresize: builtins.bool
    disk_autoresize_limit: builtins.float
    disk_size: builtins.float
    disk_type: builtins.str
    pricing_plan: builtins.str
    tier: builtins.str
    @property
    def user_labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    version: builtins.float
    @property
    def active_directory_config(self) -> global___SqlDatabaseInstanceXSettingsXActiveDirectoryConfig: ...
    @property
    def backup_configuration(self) -> global___SqlDatabaseInstanceXSettingsXBackupConfiguration: ...
    @property
    def database_flags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SqlDatabaseInstanceXSettingsXDatabaseFlags]: ...
    @property
    def insights_config(self) -> global___SqlDatabaseInstanceXSettingsXInsightsConfig: ...
    @property
    def ip_configuration(self) -> global___SqlDatabaseInstanceXSettingsXIpConfiguration: ...
    @property
    def location_preference(self) -> global___SqlDatabaseInstanceXSettingsXLocationPreference: ...
    @property
    def maintenance_window(self) -> global___SqlDatabaseInstanceXSettingsXMaintenanceWindow: ...
    @property
    def sql_server_audit_config(self) -> global___SqlDatabaseInstanceXSettingsXSqlServerAuditConfig: ...
    def __init__(
        self,
        *,
        activation_policy: builtins.str = ...,
        availability_type: builtins.str = ...,
        collation: builtins.str = ...,
        disk_autoresize: builtins.bool = ...,
        disk_autoresize_limit: builtins.float = ...,
        disk_size: builtins.float = ...,
        disk_type: builtins.str = ...,
        pricing_plan: builtins.str = ...,
        tier: builtins.str = ...,
        user_labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        version: builtins.float = ...,
        active_directory_config: global___SqlDatabaseInstanceXSettingsXActiveDirectoryConfig | None = ...,
        backup_configuration: global___SqlDatabaseInstanceXSettingsXBackupConfiguration | None = ...,
        database_flags: collections.abc.Iterable[global___SqlDatabaseInstanceXSettingsXDatabaseFlags] | None = ...,
        insights_config: global___SqlDatabaseInstanceXSettingsXInsightsConfig | None = ...,
        ip_configuration: global___SqlDatabaseInstanceXSettingsXIpConfiguration | None = ...,
        location_preference: global___SqlDatabaseInstanceXSettingsXLocationPreference | None = ...,
        maintenance_window: global___SqlDatabaseInstanceXSettingsXMaintenanceWindow | None = ...,
        sql_server_audit_config: global___SqlDatabaseInstanceXSettingsXSqlServerAuditConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["active_directory_config", b"active_directory_config", "backup_configuration", b"backup_configuration", "insights_config", b"insights_config", "ip_configuration", b"ip_configuration", "location_preference", b"location_preference", "maintenance_window", b"maintenance_window", "sql_server_audit_config", b"sql_server_audit_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activation_policy", b"activation_policy", "active_directory_config", b"active_directory_config", "availability_type", b"availability_type", "backup_configuration", b"backup_configuration", "collation", b"collation", "database_flags", b"database_flags", "disk_autoresize", b"disk_autoresize", "disk_autoresize_limit", b"disk_autoresize_limit", "disk_size", b"disk_size", "disk_type", b"disk_type", "insights_config", b"insights_config", "ip_configuration", b"ip_configuration", "location_preference", b"location_preference", "maintenance_window", b"maintenance_window", "pricing_plan", b"pricing_plan", "sql_server_audit_config", b"sql_server_audit_config", "tier", b"tier", "user_labels", b"user_labels", "version", b"version"]) -> None: ...

global___SqlDatabaseInstanceXSettings = SqlDatabaseInstanceXSettings

@typing_extensions.final
class SqlDatabaseInstanceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___SqlDatabaseInstanceXTimeouts = SqlDatabaseInstanceXTimeouts

@typing_extensions.final
class SqlDatabaseInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class IpAddressEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ServerCaCertEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONNECTION_NAME_FIELD_NUMBER: builtins.int
    DATABASE_VERSION_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    ENCRYPTION_KEY_NAME_FIELD_NUMBER: builtins.int
    FIRST_IP_ADDRESS_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    MASTER_INSTANCE_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_IP_ADDRESS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PUBLIC_IP_ADDRESS_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    ROOT_PASSWORD_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SERVER_CA_CERT_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_EMAIL_ADDRESS_FIELD_NUMBER: builtins.int
    REPLICA_CONFIGURATION_FIELD_NUMBER: builtins.int
    RESTORE_BACKUP_CONTEXT_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    connection_name: builtins.str
    database_version: builtins.str
    deletion_protection: builtins.bool
    encryption_key_name: builtins.str
    first_ip_address: builtins.str
    id: builtins.str
    @property
    def ip_address(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    master_instance_name: builtins.str
    name: builtins.str
    private_ip_address: builtins.str
    project: builtins.str
    public_ip_address: builtins.str
    region: builtins.str
    root_password: builtins.str
    self_link: builtins.str
    @property
    def server_ca_cert(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    service_account_email_address: builtins.str
    @property
    def replica_configuration(self) -> global___SqlDatabaseInstanceXReplicaConfiguration: ...
    @property
    def restore_backup_context(self) -> global___SqlDatabaseInstanceXRestoreBackupContext: ...
    @property
    def settings(self) -> global___SqlDatabaseInstanceXSettings: ...
    @property
    def timeouts(self) -> global___SqlDatabaseInstanceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        connection_name: builtins.str = ...,
        database_version: builtins.str = ...,
        deletion_protection: builtins.bool = ...,
        encryption_key_name: builtins.str = ...,
        first_ip_address: builtins.str = ...,
        id: builtins.str = ...,
        ip_address: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        master_instance_name: builtins.str = ...,
        name: builtins.str = ...,
        private_ip_address: builtins.str = ...,
        project: builtins.str = ...,
        public_ip_address: builtins.str = ...,
        region: builtins.str = ...,
        root_password: builtins.str = ...,
        self_link: builtins.str = ...,
        server_ca_cert: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        service_account_email_address: builtins.str = ...,
        replica_configuration: global___SqlDatabaseInstanceXReplicaConfiguration | None = ...,
        restore_backup_context: global___SqlDatabaseInstanceXRestoreBackupContext | None = ...,
        settings: global___SqlDatabaseInstanceXSettings | None = ...,
        timeouts: global___SqlDatabaseInstanceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["replica_configuration", b"replica_configuration", "resource_info", b"resource_info", "restore_backup_context", b"restore_backup_context", "settings", b"settings", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection_name", b"connection_name", "database_version", b"database_version", "deletion_protection", b"deletion_protection", "encryption_key_name", b"encryption_key_name", "first_ip_address", b"first_ip_address", "id", b"id", "ip_address", b"ip_address", "master_instance_name", b"master_instance_name", "name", b"name", "private_ip_address", b"private_ip_address", "project", b"project", "public_ip_address", b"public_ip_address", "region", b"region", "replica_configuration", b"replica_configuration", "resource_info", b"resource_info", "restore_backup_context", b"restore_backup_context", "root_password", b"root_password", "self_link", b"self_link", "server_ca_cert", b"server_ca_cert", "service_account_email_address", b"service_account_email_address", "settings", b"settings", "timeouts", b"timeouts"]) -> None: ...

global___SqlDatabaseInstance = SqlDatabaseInstance

@typing_extensions.final
class SqlSourceRepresentationInstanceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___SqlSourceRepresentationInstanceXTimeouts = SqlSourceRepresentationInstanceXTimeouts

@typing_extensions.final
class SqlSourceRepresentationInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_VERSION_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    database_version: builtins.str
    host: builtins.str
    id: builtins.str
    name: builtins.str
    port: builtins.float
    project: builtins.str
    region: builtins.str
    @property
    def timeouts(self) -> global___SqlSourceRepresentationInstanceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        database_version: builtins.str = ...,
        host: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        port: builtins.float = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        timeouts: global___SqlSourceRepresentationInstanceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["database_version", b"database_version", "host", b"host", "id", b"id", "name", b"name", "port", b"port", "project", b"project", "region", b"region", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___SqlSourceRepresentationInstance = SqlSourceRepresentationInstance

@typing_extensions.final
class SqlSslCertXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___SqlSslCertXTimeouts = SqlSslCertXTimeouts

@typing_extensions.final
class SqlSslCert(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERT_FIELD_NUMBER: builtins.int
    CERT_SERIAL_NUMBER_FIELD_NUMBER: builtins.int
    COMMON_NAME_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    EXPIRATION_TIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    PRIVATE_KEY_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SERVER_CA_CERT_FIELD_NUMBER: builtins.int
    SHA1_FINGERPRINT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    cert: builtins.str
    cert_serial_number: builtins.str
    common_name: builtins.str
    create_time: builtins.str
    expiration_time: builtins.str
    id: builtins.str
    instance: builtins.str
    private_key: builtins.str
    project: builtins.str
    server_ca_cert: builtins.str
    sha1_fingerprint: builtins.str
    @property
    def timeouts(self) -> global___SqlSslCertXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        cert: builtins.str = ...,
        cert_serial_number: builtins.str = ...,
        common_name: builtins.str = ...,
        create_time: builtins.str = ...,
        expiration_time: builtins.str = ...,
        id: builtins.str = ...,
        instance: builtins.str = ...,
        private_key: builtins.str = ...,
        project: builtins.str = ...,
        server_ca_cert: builtins.str = ...,
        sha1_fingerprint: builtins.str = ...,
        timeouts: global___SqlSslCertXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cert", b"cert", "cert_serial_number", b"cert_serial_number", "common_name", b"common_name", "create_time", b"create_time", "expiration_time", b"expiration_time", "id", b"id", "instance", b"instance", "private_key", b"private_key", "project", b"project", "resource_info", b"resource_info", "server_ca_cert", b"server_ca_cert", "sha1_fingerprint", b"sha1_fingerprint", "timeouts", b"timeouts"]) -> None: ...

global___SqlSslCert = SqlSslCert

@typing_extensions.final
class SqlUserXSqlServerUserDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISABLED_FIELD_NUMBER: builtins.int
    SERVER_ROLES_FIELD_NUMBER: builtins.int
    disabled: builtins.bool
    @property
    def server_roles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        disabled: builtins.bool = ...,
        server_roles: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled", b"disabled", "server_roles", b"server_roles"]) -> None: ...

global___SqlUserXSqlServerUserDetails = SqlUserXSqlServerUserDetails

@typing_extensions.final
class SqlUserXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___SqlUserXTimeouts = SqlUserXTimeouts

@typing_extensions.final
class SqlUser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETION_POLICY_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SQL_SERVER_USER_DETAILS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    deletion_policy: builtins.str
    host: builtins.str
    id: builtins.str
    instance: builtins.str
    name: builtins.str
    password: builtins.str
    project: builtins.str
    type: builtins.str
    @property
    def sql_server_user_details(self) -> global___SqlUserXSqlServerUserDetails: ...
    @property
    def timeouts(self) -> global___SqlUserXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        deletion_policy: builtins.str = ...,
        host: builtins.str = ...,
        id: builtins.str = ...,
        instance: builtins.str = ...,
        name: builtins.str = ...,
        password: builtins.str = ...,
        project: builtins.str = ...,
        type: builtins.str = ...,
        sql_server_user_details: global___SqlUserXSqlServerUserDetails | None = ...,
        timeouts: global___SqlUserXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "sql_server_user_details", b"sql_server_user_details", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deletion_policy", b"deletion_policy", "host", b"host", "id", b"id", "instance", b"instance", "name", b"name", "password", b"password", "project", b"project", "resource_info", b"resource_info", "sql_server_user_details", b"sql_server_user_details", "timeouts", b"timeouts", "type", b"type"]) -> None: ...

global___SqlUser = SqlUser



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CustomDataIdentifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    REGEX_FIELD_NUMBER: builtins.int
    MAXIMUM_MATCH_DISTANCE_FIELD_NUMBER: builtins.int
    KEYWORDS_FIELD_NUMBER: builtins.int
    IGNORE_WORDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    description: builtins.str
    regex: builtins.str
    maximum_match_distance: builtins.int
    @property
    def keywords(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ignore_words(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        regex: builtins.str = ...,
        maximum_match_distance: builtins.int = ...,
        keywords: collections.abc.Iterable[builtins.str] | None = ...,
        ignore_words: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "ignore_words", b"ignore_words", "keywords", b"keywords", "maximum_match_distance", b"maximum_match_distance", "name", b"name", "regex", b"regex", "resource_info", b"resource_info"]) -> None: ...

global___CustomDataIdentifier = CustomDataIdentifier

@typing_extensions.final
class Macie(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUSTOM_DATA_IDENTIFIER_FIELD_NUMBER: builtins.int
    FINDINGS_FILTER_FIELD_NUMBER: builtins.int
    SESSION_FIELD_NUMBER: builtins.int
    FINDINGS_FILTER_FINDINGS_FILTER_LIST_ITEM_FIELD_NUMBER: builtins.int
    @property
    def custom_data_identifier(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CustomDataIdentifier]: ...
    @property
    def findings_filter(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FindingsFilter]: ...
    @property
    def session(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Session]: ...
    @property
    def findings_filter_findings_filter_list_item(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FindingsFilterFindingsFilterListItem]: ...
    def __init__(
        self,
        *,
        custom_data_identifier: collections.abc.Iterable[global___CustomDataIdentifier] | None = ...,
        findings_filter: collections.abc.Iterable[global___FindingsFilter] | None = ...,
        session: collections.abc.Iterable[global___Session] | None = ...,
        findings_filter_findings_filter_list_item: collections.abc.Iterable[global___FindingsFilterFindingsFilterListItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_data_identifier", b"custom_data_identifier", "findings_filter", b"findings_filter", "findings_filter_findings_filter_list_item", b"findings_filter_findings_filter_list_item", "session", b"session"]) -> None: ...

global___Macie = Macie

@typing_extensions.final
class FindingsFilterCriterion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> None: ...

global___FindingsFilterCriterion = FindingsFilterCriterion

@typing_extensions.final
class FindingsFilterFindingCriteria(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CRITERION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def criterion(self) -> global___FindingsFilterCriterion: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        criterion: global___FindingsFilterCriterion | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["criterion", b"criterion", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["criterion", b"criterion", "resource_info", b"resource_info"]) -> None: ...

global___FindingsFilterFindingCriteria = FindingsFilterFindingCriteria

@typing_extensions.final
class FindingsFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FINDING_CRITERIA_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    POSITION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    description: builtins.str
    @property
    def finding_criteria(self) -> global___FindingsFilterFindingCriteria: ...
    action: builtins.str
    position: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        finding_criteria: global___FindingsFilterFindingCriteria | None = ...,
        action: builtins.str = ...,
        position: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["finding_criteria", b"finding_criteria", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "description", b"description", "finding_criteria", b"finding_criteria", "name", b"name", "position", b"position", "resource_info", b"resource_info"]) -> None: ...

global___FindingsFilter = FindingsFilter

@typing_extensions.final
class Session(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    FINDING_PUBLISHING_FREQUENCY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    status: builtins.str
    finding_publishing_frequency: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        status: builtins.str = ...,
        finding_publishing_frequency: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["finding_publishing_frequency", b"finding_publishing_frequency", "resource_info", b"resource_info", "status", b"status"]) -> None: ...

global___Session = Session

@typing_extensions.final
class FindingsFilterFindingsFilterListItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    id: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___FindingsFilterFindingsFilterListItem = FindingsFilterFindingsFilterListItem
